//These codes are to replicate the baseline results for the paper "Macroeconomic Consequences of Tariffs"
//The output will be automatically stored in the accompanying excel file
//September 2018

capture log close
clear *
set more off
set matsize 4000

cd "Q:\DOC\OE\Swarnali\Trade_tariff\Breaks\Break_regressions\checked_data\Replicate_folder" //change the directory to your local directory
use "macro_dataset.dta"

gen counter = .
tsset ifscode year, yearly 


********************************************
*Dependent variables			      	   *
*                                          *   
*										   *
********************************************

****Output***
gen lny=ln(ngdp_r)
gen f1=lny-l.lny
gen f2=f.lny-l.lny
gen f3=f2.lny-l.lny
gen f4=f3.lny-l.lny
gen f5=f4.lny-l.lny
gen f6=f5.lny-l.lny

****Real effective exchange rate***
gen lle=ln(reer)
gen u1=lle-l.lle
gen u2=f.lle-l.lle
gen u3=f2.lle-l.lle
gen u4=f3.lle-l.lle
gen u5=f4.lle-l.lle
gen u6=f5.lle-l.lle

****Trade balance (share of GDP)***
gen lna= tb
gen a1=lna-l.lna
gen a2=f.lna-l.lna
gen a3=f2.lna-l.lna
gen a4=f3.lna-l.lna
gen a5=f4.lna-l.lna
gen a6=f5.lna-l.lna


****Unemployment rate***
gen lnb=lur
gen b1=lnb-l.lnb
gen b2=f.lnb-l.lnb
gen b3=f2.lnb-l.lnb
gen b4=f3.lnb-l.lnb
gen b5=f4.lnb-l.lnb
gen b6=f5.lnb-l.lnb

****Productivity***
gen lnp=lny-ln(le)
gen p1=lnp-l.lnp
gen p2=f.lnp-l.lnp
gen p3=f2.lnp-l.lnp
gen p4=f3.lnp-l.lnp
gen p5=f4.lnp-l.lnp
gen p6=f5.lnp-l.lnp

****Inequality***
gen lni=gini_net_50
gen i1=lni-l.lni
gen i2=f.lni-l.lni
gen i3=f2.lni-l.lni
gen i4=f3.lni-l.lni
gen i5=f4.lni-l.lni
gen i6=f5.lni-l.lni


********************************************
*Shock	predefined						   *
*                                          *   
*
********************************************

//define shock
gen shock=d.tariff                    


********************************************
*Local projection			               *
*                                          *   
*
********************************************

preserve
//to keep track of the time periods for result
replace counter = 0 if _n==2
replace counter = 1 if _n==3
replace counter = 2 if _n==4
replace counter = 3 if _n==5
replace counter = 4 if _n==6
replace counter = 5 if _n==7

****Output****
gen b_f=.
gen se_f=.
	
forvalues y = 1/6 {
		xtscc f`y' l(0/2)shock l(1/2)f1 l(1/2)a1 l(1/2)u1  i.year  , fe
			
		replace b_f =  _b[shock] if _n==`y'+1
		replace se_f = _se[shock] if _n==`y'+1
			}

			
****reer***
gen b_u=.
gen se_u=.
	
forvalues y = 1/6 {
		xtscc u`y' l(0/2)shock l(1/2)f1 l(1/2)a1 l(1/2)u1  i.year  , fe
			
		replace b_u =  _b[shock] if _n==`y'+1
		replace se_u = _se[shock] if _n==`y'+1
			}


**TB**
gen b_a=.
gen se_a=.
	
forvalues y = 1/6 {
		xtscc a`y' l(0/2)shock l(1/2)f1 l(1/2)a1 l(1/2)u1  i.year  , fe
			
		replace b_a =  _b[shock] if _n==`y'+1
		replace se_a = _se[shock] if _n==`y'+1
			}


****unemployment rate***
gen b_b=.
gen se_b=.
	
forvalues y = 1/6 {
		xtscc b`y' l(0/2)shock l(1/2)f1 l(1/2)a1 l(1/2)u1  i.year l(1/2)b1 , fe
			
		replace b_b =  _b[shock] if _n==`y'+1
		replace se_b = _se[shock] if _n==`y'+1
			}


****productivity***
gen b_p=.
gen se_p=.
	
forvalues y = 1/6 {
		xtscc p`y' l(0/2)shock l(1/2)f1 l(1/2)a1 l(1/2)u1  i.year l(1/2)p1 , fe
			
		replace b_p =  _b[shock] if _n==`y'+1
		replace se_p = _se[shock] if _n==`y'+1
			}


****inequality***
gen b_i=.
gen se_i=.
	
forvalues y = 1/6 {
		xtscc i`y' l(0/2)shock l(1/2)f1 l(1/2)a1 l(1/2)u1  i.year l(1/2)i1 , fe
			
		replace b_i =  _b[shock] if _n==`y'+1
		replace se_i = _se[shock] if _n==`y'+1
			}

	
//store the results in excel
keep counter b_* se_* 
order counter, first
drop if _n>8

//enter the name of your local directory
export excel "Q:\DOC\OE\Swarnali\Trade_tariff\Breaks\Break_regressions\checked_data\Replicate_folder\results.xlsx", sheet("Stata_baseline") firstrow(variables) sheetreplace

restore

